@@ -1,9 +1,8 @@
 from ._pim import MongoClient
 from .mongod import Mongod
-from .downloader import bin_folder, download
+from .downloader import download
 
 __all__ = [
-    "bin_folder",
     "download",
     "MongoClient",
     "Mongod",
